
import * as React from 'react';
import {
  Table,
} from 'semantic-ui-react';


export interface Props {
  columnList?: string[];
  onHeaderColumnClick?(col:string, direction: string): void;
}

export interface State {
  column: string;
  direction: 'ascending' | 'descending';
}


export class SortTableHeaderRow extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      column: null,
      direction: null,
    };
  }

  public render(): JSX.Element {
    return (
      <Table.Row>
        {this.renderCell()}
      </Table.Row>
    );
  }

  private renderCell = (): (JSX.Element | JSX.Element[]) => {
    let arr = [];
    let idx:number = 0;

    for (let colValue of this.props.columnList) {

      arr.push(
        <Table.HeaderCell key={idx++} textAlign={'center'}
          sorted={this.state.column === colValue ? this.state.direction : 'ascending'}
          onClick={this.handleColumnSort(colValue)}>{colValue}</Table.HeaderCell>);
    }

    return arr;
  }

  private handleColumnSort = (col:string) => ():void => {
    if (this.state.column !== col) {
      this.setState({
        column: col,
        direction: 'ascending',
      });
    } else {
      this.setState({
        direction: this.state.direction === 'ascending' ? 'descending' : 'ascending',
      });
    }

    this.props.onHeaderColumnClick(this.state.column, this.state.direction);

  }

}

